@@ -15,7 +15,7 @@ fbGetAdAccounts <- function(source_id    = getOption("rfacebookstat.business_id"
     }
   }
   
-  if ( class(access_token) == "fb_access_token" ) {
+  if ( inherits(access_token, "fb_access_token") ) {
     
     access_token <- access_token$access_token
     
@@ -50,7 +50,7 @@ fbGetAdAccounts <- function(source_id    = getOption("rfacebookstat.business_id"
     # send request
     answer  <- GET(url, 
                    query = list(fields       = "id,name,account_id,account_status,amount_spent,created_time,balance,business_name,media_agency,currency,owner,partner,age,timezone_name,disable_reason",
-                                limit        = 1000,
+                                limit        = 300,
                                 access_token = access_token))
 
     # attr
@@ -106,4 +106,4 @@ fbGetAdAccounts <- function(source_id    = getOption("rfacebookstat.business_id"
   attr(result, "headers")     <- out_headers
   return(result)
 }
-  
\ No newline at end of file
+  
