@@ -15,7 +15,7 @@ fbGetCatalogs <- function(business_id  = getOption("rfacebookstat.business_id")
     }
   }
   
-  if ( class(access_token) == "fb_access_token" ) {
+  if ( inherits(access_token, "fb_access_token") ) {
     
     access_token <- access_token$access_token
     
@@ -73,4 +73,4 @@ fbGetCatalogs <- function(business_id  = getOption("rfacebookstat.business_id")
   attr(result, "headers")     <- out_headers
   
   return(result)
-}
\ No newline at end of file
+}
